==> 3.4.1.tar.gz: xbackbone/resources/lang/sv.lang.php <==
<?php
return [
    'cannot_delete' => 'Du kan inte ta bort dig själv.',
    'user_deleted' => 'Användare borttagen.',
    'profile_updated' => 'Profiluppdatering lyckades!',
    'user_updated' => 'Användare ”%s” uppdaterad!',
    'user_created' => 'Användare ”%s” skapad!',
    'password_required' => 'Lösenord krävs.',
    'username_taken' => 'Användarnamnet används redan.',
    'username_required' => 'Användarnamn krävs.',
    'email_taken' => 'E-postadressen används redan.',
    'email_required' => 'E-postadress krävs.',
    'goodbye' => 'Hejdå!',
    'welcome' => 'Välkommen, %s!',
    'account_disabled' => 'Ditt konto är avstängt.',
    'bad_login' => 'Fel uppgifter.',
    'installed' => 'Installationen lyckades!',
    'confirm_string' => 'Är du säker?',
    'open' => 'Öppna',
    'none' => 'Ingen',
    'reg_date' => 'Registreringsdatum',
    'admin' => 'Admin',
    'active' => 'Aktiv',
    'user_code' => 'Användarkod',
    'client_config' => 'Klientkonfiguration',
    'edit' => 'Ändra',
    'update' => 'Uppdatera',
    'copy' => 'Kopiera',
    'your_profile' => 'Din profil',
    'is_admin' => 'Är administratör',
    'is_active' => 'Är aktiv',
    'user.edit' => 'Ändra Användare',
    'user.create' => 'Skapa användare',
    'system_settings' => 'Systeminställningar',
    'php_info' => 'PHP-Information',
    'used' => 'Använd',
    'save' => 'Spara',
    'apply' => 'Applicera',
    'click_to_load' => 'Klicka för att ladda…',
    'theme' => 'Tema',
    'files' => 'Filer',
    'hide' => 'Göm',
    'publish' => 'Publicera',
    'delete' => 'Ta bort',
    'upload' => 'Ladda upp',
    'download' => 'Ladda ner',
    'raw' => 'Visa omodifierad',
    'date' => 'Datum',
    'owner' => 'Ägare',
    'public' => 'Offentligt',
    'size' => 'Storlek',
    'filename' => 'Filnamn',
    'preview' => 'Förhandsgranskning',
    'public.delete_text' => 'Är du säker på att du vill ta bort detta? Det går inte att återställa',
    'public.telegram' => 'Dela på Telegram',
    'copy_link' => 'Kopiera länken',
    'pager.previous' => 'Tidigare',
    'pager.next' => 'Nästa',
    'logout' => 'Logga ut',
    'profile' => 'Profil',
    'system' => 'System',
    'users' => 'Användare',
    'home' => 'Hem',
    'username' => 'Användarnamn',
    'login' => 'Inloggning',
    'password' => 'Lösenord',
    'login.username' => 'Användarnamn eller e-post',
    'no_media' => 'Ingen media kunde hittas.',
    'send' => 'Skicka',
    'no' => 'Nej',
    'yes' => 'Ja',
    'lang' => 'Engelska',
    'enforce_language' => 'Verkställ språk',
    'show_changelog' => 'Visa förändringslogg',
    'changelog' => 'Förändringslogg',
    'zip_ext_not_loaded' => 'Det nödvändiga "zip"-tillägget har ej laddats',
    'auto_tagging' => 'Automatisk taggning av uppladdningar',
    'no_tags' => 'Inga taggar tillagt',
    'upload_max_file_size' => 'Den maximala filstorleken är för närvarande %s.',
    'ldap_cant_connect' => 'Kan ej ansluta till LDAP auth-servern.',
    'user_create_password' => 'Om fältet lämnas blankt bör du skicka ett meddelande till användarens e-postadress.',
    'mail.new_account_text_with_pw' => 'Hej %s!<br>ett nytt konto skapades åt dig hos %s (<a href="%s">%s</a>), med följande inloggningsuppgifter:<br><br>Användarnamn: %s<br>Lösenord: %s<br><br>Klicka på följande länk för att logga in:<br><a href="%s">%s</a>',
    'mail.new_account_text_with_reset' => 'Hej %s!<br>ett nytt konto skapades för dig hos %s (<a href="%s">%s</a>), klicka på följande länk för att ställa in lösenord och aktivera kontot:<br><br><a href="%s">%s</a>',
    'mail.new_account' => '%s - Skapa Nytt Konto',
    'send_notification' => 'Skicka påminnelser via mejl',
    'recaptcha_secret_key' => 'reCAPTCHA Secret Key',
    'recaptcha_site_key' => 'reCAPTCHA Site Key',
    'only_recaptcha_v3' => 'Endast reCAPTCHA v3 stöds.',
    'recaptcha_keys_required' => 'Alla reCAPTCHA-nycklar är obligatoriska.',
    'recaptcha_enabled' => 'reCAPTCHA Aktiverad',
    'recaptcha_failed' => 'reCAPTCHA Misslyckades',
    'danger_zone' => 'Farozon',
    'account_media_deleted' => 'All media på kontot har raderats.',
    'clear_account' => 'Rensa Konto',
    'delete_all' => 'Radera Alla',
    'delete_selected' => 'Radera Markerat',
    'used_space' => 'Använt Utrymme',
    'quota_recalculated' => 'Omräkning av användarkvot lyckades.',
    'recalculate_user_quota' => 'Räkna om användarkvot från disk',
    'password_restored' => 'Lösenordsåterställning.',
    'password_match' => 'Lösenordet och det bekräftade lösenordet måste stämma överens.',
    'password_repeat' => 'Bekräfta Lösenord',
    'quota_enabled' => 'Aktivera användarkvot',
    'account_activated' => 'Konto aktiverades, nu kan du logga in!',
    'recover_email_sent' => 'Om tillgängligt skickades ett mejl med återställning av lösenord till det angivna kontot.',
    'mail.recover_password' => '%s - Återställning av Lösenord',
    'mail.recover_text' => 'Hej %s,<br>en återställning av lösenord har begärts för ditt konto. För att utföra återställningen, klicka på följande länk:<br><br><a href="%s">%s</a><br><br>Om du inte begärt återställning av lösenord kan du ignorera detta mejl.',
    'mail.activate_account' => '%s - Kontoaktivering',
    'mail.activate_text' => 'Hej %s!<br>tack för att du skapat ett konto hos %s (<a href="%s">%s</a>), klicka på följande länk för att aktivera:<br><br><a href="%s">%s</a>',
    'invalid_quota' => 'Ogiltiga värden som standard användarkvot.',
    'max_user_quota' => 'Maximal Användarkvot',
    'default_user_quota' => 'Användarkvot som standard',
    'register_success' => 'Kontot skapades, ett bekräftelsemejl har skickats.',
    'register' => 'Registrera',
    'no_account' => 'Inget konto?',
    'password_recovery' => 'Återställ lösenord',
    'export_data' => 'Exportera data',
    'settings_saved' => 'Systeminställningar sparades!',
    'copy_url_behavior' => 'Kopiera URL-läge',
    'hide_by_default' => 'Dölj media som standard',
    'register_enabled' => 'Registrering aktiverad',
    'dont_close' => 'Stäng ej denna tabb innan processen är klar.',
    'please_wait' => 'Vänligen vänta…',
    'remember_me' => 'Kom ihåg mig',
    'custom_head_html' => 'Anpassat HTML Head-innehåll',
    'custom_head_set' => 'Anpassad HTML head tillämpad.',
    'custom_head_html_hint' => 'Innehållet kommer läggas till i <head>-taggen på varje sida.',
    'donate_text' => 'Om du gillar XBackBone, överväg att donera för att främja fortsatt utveckling!',
    'donation' => 'Donera',
    'drop_to_upload' => 'Klicka eller släpp dina filer här för att ladda upp.',
    'no_upload_token' => 'Du har ingen personlig uppladdningstoken (Skapa en och försök igen.)',
    'prerelease_channel' => 'Kanal för tidiga utgåvor',
    'default_lang_behavior' => 'XBackBone kommer försöka matcha webbläsarens språk som standard (Engelska är i reserv).',
    'auto_set' => 'Ställ in automatiskt',
    'cancel' => 'Avbryt',
    'maintenance_in_progress' => 'Plattformen genomgår underhåll, försök igen senare…',
    'updates' => 'Uppdateringar',
    'upgrade' => 'Uppgradera',
    'check_for_updates' => 'Sök efter uppdateringar',
    'file_size_no_match' => 'Den nedladdade filen matchar ej den korrekta filstorleken.',
    'cannot_retrieve_file' => 'Kan ej hämta filen.',
    'new_version_available' => 'Ny version %s tillgänglig!',
    'already_latest_version' => 'Du har redan den senaste versionen.',
    'path_not_writable' => 'Den utgående sökvägen är ej skrivbar.',
    'clean_orphaned_uploads' => 'Rensa Föräldralösa Uppladdningar',
    'maintenance' => 'Underhåll',
    'name' => 'Namn',
    'time' => 'Tid',
    'order_by' => 'Sortera efter…',
    'dotted_search' => 'Sök…',
    'table' => 'Tabell',
    'gallery' => 'Galleri',
    'switch_to' => 'Byt till',
    'deleted_orphans' => 'Borttagning av %d föräldralösa filer lyckades.',
    'cannot_write_file' => 'Destinationens sökväg är ej skrivbar.',
    'cannot_demote' => 'Du kan inte degradera dig själv.',
    'token_not_found' => 'Den token som angavs hittades inte.',
    'confirm' => 'Bekräftelse',
    'copied' => 'Kopierat till urklipp!',
    'token' => 'Token',
    'orphaned_files' => 'Föräldralösa Filer',
];

==> 3.7.0.tar.gz: xbackbone/resources/lang/sv.lang.php <==
<?php
return [
    'cannot_delete' => 'Du kan inte ta bort dig själv.',
    'user_deleted' => 'Användare borttagen.',
    'profile_updated' => 'Profiluppdatering lyckades!',
    'user_updated' => 'Användare ”%s” uppdaterad!',
    'user_created' => 'Användare ”%s” skapad!',
    'password_required' => 'Lösenord krävs.',
    'username_taken' => 'Användarnamnet används redan.',
    'username_required' => 'Användarnamn krävs.',
    'email_taken' => 'E-postadressen används redan.',
    'email_required' => 'E-postadress krävs.',
    'goodbye' => 'Hejdå!',
    'welcome' => 'Välkommen, %s!',
    'account_disabled' => 'Ditt konto är avstängt.',
    'bad_login' => 'Fel uppgifter.',
    'installed' => 'Installationen lyckades!',
    'confirm_string' => 'Är du säker?',
    'open' => 'Öppna',
    'none' => 'Ingen',
    'reg_date' => 'Registreringsdatum',
    'admin' => 'Admin',
    'active' => 'Aktiv',
    'user_code' => 'Användarkod',
    'client_config' => 'Klientkonfiguration',
    'edit' => 'Ändra',
    'update' => 'Uppdatera',
    'copy' => 'Kopiera',
    'your_profile' => 'Din profil',
    'is_admin' => 'Är administratör',
    'is_active' => 'Är aktiv',
    'user.edit' => 'Ändra Användare',
    'user.create' => 'Skapa användare',
    'system_settings' => 'Systeminställningar',
    'php_info' => 'PHP-Information',
    'used' => 'Använd',
    'save' => 'Spara',
    'apply' => 'Applicera',
    'click_to_load' => 'Klicka för att ladda…',
    'theme' => 'Tema',
    'files' => 'Filer',
    'hide' => 'Göm',
    'publish' => 'Publicera',
    'delete' => 'Ta bort',
    'upload' => 'Ladda upp',
    'download' => 'Ladda ner',
    'raw' => 'Visa omodifierad',
    'date' => 'Datum',
    'owner' => 'Ägare',
    'public' => 'Offentligt',
    'size' => 'Storlek',
    'filename' => 'Filnamn',
    'preview' => 'Förhandsgranskning',
    'public.delete_text' => 'Är du säker på att du vill ta bort detta? Det går inte att återställa',
    'public.telegram' => 'Dela på Telegram',
    'copy_link' => 'Kopiera länken',
    'pager.previous' => 'Tidigare',
    'pager.next' => 'Nästa',
    'logout' => 'Logga ut',
    'profile' => 'Profil',
    'system' => 'System',
    'users' => 'Användare',
    'home' => 'Hem',
    'username' => 'Användarnamn',
    'login' => 'Inloggning',
    'password' => 'Lösenord',
    'login.username' => 'Användarnamn eller e-post',
    'no_media' => 'Ingen media kunde hittas.',
    'send' => 'Skicka',
    'no' => 'Nej',
    'yes' => 'Ja',
    'lang' => 'Engelska',
    'enforce_language' => 'Verkställ språk',
    'show_changelog' => 'Visa förändringslogg',
    'changelog' => 'Förändringslogg',
    'zip_ext_not_loaded' => 'Det nödvändiga "zip"-tillägget har ej laddats',
    'auto_tagging' => 'Automatisk taggning av uppladdningar',
    'no_tags' => 'Inga taggar tillagt',
    'upload_max_file_size' => 'Den maximala filstorleken är för närvarande %s.',
    'ldap_cant_connect' => 'Kan ej ansluta till LDAP auth-servern.',
    'user_create_password' => 'Om fältet lämnas blankt bör du skicka ett meddelande till användarens e-postadress.',
    'mail.new_account_text_with_pw' => 'Hej %s!<br>ett nytt konto skapades åt dig hos %s (<a href="%s">%s</a>), med följande inloggningsuppgifter:<br><br>Användarnamn: %s<br>Lösenord: %s<br><br>Klicka på följande länk för att logga in:<br><a href="%s">%s</a>',
    'mail.new_account_text_with_reset' => 'Hej %s!<br>ett nytt konto skapades för dig hos %s (<a href="%s">%s</a>), klicka på följande länk för att ställa in lösenord och aktivera kontot:<br><br><a href="%s">%s</a>',
    'mail.new_account' => '%s - Skapa Nytt Konto',
    'send_notification' => 'Skicka påminnelser via mejl',
    'recaptcha_secret_key' => 'reCAPTCHA Secret Key',
    'recaptcha_site_key' => 'reCAPTCHA Site Key',
    'only_recaptcha_v3' => 'Endast reCAPTCHA v3 stöds.',
    'recaptcha_keys_required' => 'Alla reCAPTCHA-nycklar är obligatoriska.',
    'recaptcha_enabled' => 'reCAPTCHA Aktiverad',
    'recaptcha_failed' => 'reCAPTCHA Misslyckades',
    'danger_zone' => 'Farozon',
    'account_media_deleted' => 'All media på kontot har raderats.',
    'clear_account' => 'Rensa Konto',
    'delete_all' => 'Radera Alla',
    'delete_selected' => 'Radera Markerat',
    'used_space' => 'Använt Utrymme',
    'quota_recalculated' => 'Omräkning av användarkvot lyckades.',
    'recalculate_user_quota' => 'Räkna om användarkvot från disk',
    'password_restored' => 'Lösenordsåterställning.',
    'password_match' => 'Lösenordet och det bekräftade lösenordet måste stämma överens.',
    'password_repeat' => 'Bekräfta Lösenord',
    'quota_enabled' => 'Aktivera användarkvot',
    'account_activated' => 'Konto aktiverades, nu kan du logga in!',
    'recover_email_sent' => 'Om tillgängligt skickades ett mejl med återställning av lösenord till det angivna kontot.',
    'mail.recover_password' => '%s - Återställning av Lösenord',
    'mail.recover_text' => 'Hej %s,<br>en återställning av lösenord har begärts för ditt konto. För att utföra återställningen, klicka på följande länk:<br><br><a href="%s">%s</a><br><br>Om du inte begärt återställning av lösenord kan du ignorera detta mejl.',
    'mail.activate_account' => '%s - Kontoaktivering',
    'mail.activate_text' => 'Hej %s!<br>tack för att du skapat ett konto hos %s (<a href="%s">%s</a>), klicka på följande länk för att aktivera:<br><br><a href="%s">%s</a>',
    'invalid_quota' => 'Ogiltiga värden som standard användarkvot.',
    'max_user_quota' => 'Maximal Användarkvot',
    'default_user_quota' => 'Användarkvot som standard',
    'register_success' => 'Kontot skapades, ett bekräftelsemejl har skickats.',
    'register' => 'Registrera',
    'no_account' => 'Inget konto?',
    'password_recovery' => 'Återställ lösenord',
    'export_data' => 'Exportera data',
    'settings_saved' => 'Systeminställningar sparades!',
    'copy_url_behavior' => 'Kopiera URL-läge',
    'hide_by_default' => 'Dölj media som standard',
    'register_enabled' => 'Registrering aktiverad',
    'dont_close' => 'Stäng ej denna tabb innan processen är klar.',
    'please_wait' => 'Vänligen vänta…',
    'remember_me' => 'Kom ihåg mig',
    'custom_head_html' => 'Anpassat HTML Head-innehåll',
    'custom_head_set' => 'Anpassad HTML head tillämpad.',
    'custom_head_html_hint' => 'Innehållet kommer läggas till i <head>-taggen på varje sida.',
    'donate_text' => 'Om du gillar XBackBone, överväg att donera för att främja fortsatt utveckling!',
    'donation' => 'Donera',
    'drop_to_upload' => 'Klicka eller släpp dina filer här för att ladda upp.',
    'no_upload_token' => 'Du har ingen personlig uppladdningstoken (Skapa en och försök igen.)',
    'prerelease_channel' => 'Kanal för tidiga utgåvor',
    'default_lang_behavior' => 'XBackBone kommer försöka matcha webbläsarens språk som standard (Engelska är i reserv).',
    'auto_set' => 'Ställ in automatiskt',
    'cancel' => 'Avbryt',
    'maintenance_in_progress' => 'Plattformen genomgår underhåll, försök igen senare…',
    'updates' => 'Uppdateringar',
    'upgrade' => 'Uppgradera',
    'check_for_updates' => 'Sök efter uppdateringar',
    'file_size_no_match' => 'Den nedladdade filen matchar ej den korrekta filstorleken.',
    'cannot_retrieve_file' => 'Kan ej hämta filen.',
    'new_version_available' => 'Ny version %s tillgänglig!',
    'already_latest_version' => 'Du har redan den senaste versionen.',
    'path_not_writable' => 'Den utgående sökvägen är ej skrivbar.',
    'clean_orphaned_uploads' => 'Rensa Föräldralösa Uppladdningar',
    'maintenance' => 'Underhåll',
    'name' => 'Namn',
    'time' => 'Tid',
    'order_by' => 'Sortera efter…',
    'dotted_search' => 'Sök…',
    'table' => 'Tabell',
    'gallery' => 'Galleri',
    'switch_to' => 'Byt till',
    'deleted_orphans' => 'Borttagning av %d föräldralösa filer lyckades.',
    'cannot_write_file' => 'Destinationens sökväg är ej skrivbar.',
    'cannot_demote' => 'Du kan inte degradera dig själv.',
    'token_not_found' => 'Den token som angavs hittades inte.',
    'confirm' => 'Bekräfta',
    'copied' => 'Kopierat till urklipp!',
    'token' => 'Token',
    'orphaned_files' => 'Föräldralösa Filer',
    'image_embeds' => 'Inbäddade bilder',
    'vanity_url' => 'Anpassad URL',
];
